@@ -2,7 +2,7 @@ test_that("date handling is correct", {
 
   # create sf object
   x <- sf::st_sf(
-    data.frame(today = as.POSIXct(Sys.Date())),
+    data.frame(today = as.POSIXct("2001-01-01", tz = "UTC")),
     geometry = sf::st_sfc(sf::st_point(c(0, 1)), crs = 4326)
   )
 
@@ -14,7 +14,6 @@ test_that("date handling is correct", {
   # create featurset geometry
   json <- jsonify::to_json(l)
 
-
   parsed <- parse_esri_json(json)
 
   expect_identical(x$today, parsed$today)
